diff scripts/contributors.py @ 5414:3fa026621f69

Python 3 preparation: comparisons. Python 3 no longer has the cmp function, or cmp= arguments to sorting functions / methods (key= must be used instead), and requires rich comparison methods such as __lt__ to be defined instead of using __cmp__. All of the comparison mechanisms supported in Python 3 are also supported in Python 2. This patch makes the corresponding changes in Roundup to use key functions and rich comparison methods. In the case of the JournalPassword and Permission classes, only __eq__ and __ne__ are defined as I don't see ordered comparisons as useful there (and for Permission, the old __cmp__ function didn't try to provide a valid ordering). In the case of the Date class, I kept the __cmp__ method and implemented the others in terms of it, to avoid excess repetitiveness in duplicating implementation code for all six rich comparison methods. In roundup/admin.py, help_commands_html used operator.attrgetter to produce the second argument of sorted() - which would be reasonable for a key function, but the second argument is the cmp function in Python 2, not a key function (and the key function must be a named argument not a positional argument in Python 3). That function appears to be completely unused, so I expect that code never worked. This patch adds the missing key= to that sorted() call, but it would also be reasonable to remove the unused function completely instead.
author Joseph Myers <jsm@polyomino.org.uk>
date Wed, 25 Jul 2018 00:39:37 +0000
parents 64daaa4bf816
children ce171c81d823
line wrap: on
line diff
--- a/scripts/contributors.py	Wed Jul 25 00:37:54 2018 +0000
+++ b/scripts/contributors.py	Wed Jul 25 00:39:37 2018 +0000
@@ -136,19 +136,16 @@
       """Return year of the first contribution"""
       return sorted(list(names[name]))[0]
 
-    def year_cmp(name1, name2):
+    def year_key(name):
       """
       Year comparison function. First sort by latest contribution year (desc).
       If it matches, compare first contribution year (asc). This ensures that
       the most recent and long-term contributors are at the top.
       """
-      if last_year(name1) != last_year(name2):
-        return last_year(name1) - last_year(name2)
-      else:
-        return first_year(name2) - first_year(name1)
+      return (last_year(name), -first_year(name))
     
     print("Copyright (c)")
-    for author in sorted(list(names), cmp=year_cmp, reverse=True):
+    for author in sorted(list(names), key=year_key, reverse=True):
       years = list(names[author])
       yearstr = compress(years)
 
@@ -136,19 +136,16 @@
       """
-      Year comparison function. First sort by latest contribution year (desc).
+      Year key function. First sort by latest contribution year (desc).
       If it matches, compare first contribution year (asc). This ensures that
       the most recent and long-term contributors are at the top.

Roundup Issue Tracker: http://roundup-tracker.org/